==> fusenshi-0.7.5.tgz: fusenshi-0.7.5/src/include/networkfusenshidata.h <==
/*
 * $Id: networkfusenshidata.h,v 1.1 2004/04/01 08:52:40 daichi Exp $
 *
 * Copyright 2003- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.1 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___NETWORKFUSENSHIDATA_H
#define ___NETWORKFUSENSHIDATA_H

class NetworkFusenshiData : public FusenshiData
{
public:
    /**
     * 󥹥ȥ饯
     */
    NetworkFusenshiData();
    
    /**
     * ǥȥ饯
     */
    virtual ~NetworkFusenshiData();
    
    /**
     * 桼̾ޤ
     * 
     * @return 桼̾
     */
    Glib::ustring getUserName() const;

    /**
     * ۥ̾ޤ
     * 
     * @return ۥ̾
     */
    Glib::ustring getHostName() const;

    /**
     * IPɥ쥹ޤ
     * 
     * @return IPɥ쥹
     */
    Glib::ustring getIPAddr() const;
    
    /**
     * 桼̾ޤ
     * 
     * @param szUserName 桼̾
     */
    void setUserName(Glib::ustring szUserName);

    /**
     * ۥ̾ޤ
     * 
     * @param szHostName ۥ̾
     */
    void setHostName(Glib::ustring szHostName);

    /**
     * IPɥ쥹ޤ
     * 
     * @param szIPAddr IPɥ쥹
     */
    void setIPAddr(Glib::ustring szIPAddr);
    
public:
    /**
     * ꥢ饤줿䵻ǡ䵻ǡ֥Ȥ
     * ۤޤ
     * 
     * @param pData ꥢ饤ΥХ
     * @return 䵻ǡ֥ȡ
     *         פˤʤäʳ˴ɬפޤ
     */
    static FusenshiData* buildObject(const GString* pBytes);

    /**
     * 䵻ǡ֥Ȥ򥷥ꥢ饤ޤ
     * 
     * @param pData 䵻ǡ֥
     * @param szUserName 桼̾
     * @param szHostName ۥ̾
     * @param szIPAddr IPɥ쥹
     * @return ꥢ饤ΥХ
     *         פˤʤäʳ˴ɬפޤ
     */
    /**
     * ߤμǤϻѤޤ
     * 
    static GString* toSerializedString
        (const FusenshiData* pData, Glib::ustring szUserName, 
         Glib::ustring szHostName, Glib::ustring szIPAddr);
     */

protected:
    /**
     * 䵻ǡ֥Ȥ򥷥ꥢ饤ޤ
     * 
     * @param pData 䵻ǡ֥
     * @return ꥢ饤ΥХ
     *         פˤʤäʳ˴ɬפޤ
     */
    /**
     * ߤμǤϻѤޤ
     * 
    static GString* toSerializedString(const FusenshiData* pData);
     */

    /**
     * ꥢ饤줿䵻ǡκǾñ̤ϡꤷޤ
     * 
     * @param szType ǡ
     * @param szValue ǡ
     */
    virtual void parseValueAndSet
        (Glib::ustring& szType, Glib::ustring& szValue);

private:
    /**
     * 桼̾
     */
    Glib::ustring m_szUserName;

    /**
     * ۥ̾
     */
    Glib::ustring m_szHostName;

    /**
     * IPɥ쥹
     */
    Glib::ustring m_szIPAddr;
};

#endif

==> fusenshi-0.8.2.tgz: fusenshi-0.8.2/src/include/networkfusenshidata.h <==
/*
 * $Id: networkfusenshidata.h,v 1.2 2005/11/24 14:21:03 ozawa Exp $
 *
 * Copyright 2003- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.2 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___NETWORKFUSENSHIDATA_H
#define ___NETWORKFUSENSHIDATA_H

class NetworkFusenshiData : public FusenshiData
{
public:
    /**
     * 󥹥ȥ饯
     */
    NetworkFusenshiData();
    
    /**
     * ǥȥ饯
     */
    virtual ~NetworkFusenshiData();
    
    /**
     * 桼̾ޤ
     * 
     * @return 桼̾
     */
    Glib::ustring getUserName() const;

    /**
     * ۥ̾ޤ
     * 
     * @return ۥ̾
     */
    Glib::ustring getHostName() const;

    /**
     * IPɥ쥹ޤ
     * 
     * @return IPɥ쥹
     */
    Glib::ustring getIPAddr() const;
    
    /**
     * 桼̾ޤ
     * 
     * @param szUserName 桼̾
     */
    void setUserName(Glib::ustring szUserName);

    /**
     * ۥ̾ޤ
     * 
     * @param szHostName ۥ̾
     */
    void setHostName(Glib::ustring szHostName);

    /**
     * IPɥ쥹ޤ
     * 
     * @param szIPAddr IPɥ쥹
     */
    void setIPAddr(Glib::ustring szIPAddr);
    
public:
    /**
     * ꥢ饤줿䵻ǡ䵻ǡ֥Ȥ
     * ۤޤ
     * 
     * @param pData ꥢ饤ΥХ
     * @return 䵻ǡ֥ȡ
     *         פˤʤäʳ˴ɬפޤ
     */
    static FusenshiData* buildObject(const char* pData);

    /**
     * 䵻ǡ֥Ȥ򥷥ꥢ饤ޤ
     * 
     * @param pData 䵻ǡ֥
     * @param szUserName 桼̾
     * @param szHostName ۥ̾
     * @param szIPAddr IPɥ쥹
     * @return ꥢ饤ΥХ
     *         פˤʤäʳ˴ɬפޤ
     */
    /**
     * ߤμǤϻѤޤ
     * 
    static char* toSerializedString
        (const FusenshiData* pData, Glib::ustring szUserName, 
         Glib::ustring szHostName, Glib::ustring szIPAddr);
     */

protected:
    /**
     * 䵻ǡ֥Ȥ򥷥ꥢ饤ޤ
     * 
     * @param pData 䵻ǡ֥
     * @return ꥢ饤ΥХ
     *         פˤʤäʳ˴ɬפޤ
     */
    /**
     * ߤμǤϻѤޤ
     * 
    static char* toSerializedString(const FusenshiData* pData);
     */

    /**
     * ꥢ饤줿䵻ǡκǾñ̤ϡꤷޤ
     * 
     * @param szType ǡ
     * @param szValue ǡ
     */
    virtual void parseValueAndSet
        (Glib::ustring& szType, Glib::ustring& szValue);

private:
    /**
     * 桼̾
     */
    Glib::ustring m_szUserName;

    /**
     * ۥ̾
     */
    Glib::ustring m_szHostName;

    /**
     * IPɥ쥹
     */
    Glib::ustring m_szIPAddr;
};

#endif
